==> litecoin_0.16.0.orig.tar.xz: litecoin-0.16.0/src/qt/locale/bitcoin_he_IL.ts <==
<TS language="he_IL" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>קליל ימני כדי לערוך כתובת או תווית</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>צור כתובת חדשה</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>וחדש</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>העתק את הכתובת הנבחרת ללוח</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>והעתק</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>וסגור</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>מחק את הכתובת הנבחרת מהרשימה</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>יצא את המידע בעמוד הנוכחי לקובץ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ייצוא</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>בחר את הכתובת כדי לשלוח אליה מטבעות</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>בחר את הכתובת כדי לקבל אליה מטבעות</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>בחר</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>שולח כתובות</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>מקבל כתובות</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>אלו הן כתובות הלייטקוין שלך לשליחת תשלומים. תמיד בדוק את כתובת הארנק המקבל לפני שליחת מטבעות</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>אלו הן כתובות הלייטקוין שלך לקבלת תשלומים. מומלץ להשתמש בכתובת חדשה בכל העברת מטבעות</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Litecoin</source>
        <translation>לייטקוין</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>ארנק</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>העתק כמות</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Litecoin</source>
        <translation>לייטקוין</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Copy quantity</source>
        <translation>העתק כמות</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ייצוא</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>יצא את המידע בעמוד הנוכחי לקובץ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> litecoin_0.18.1.orig.tar.xz: litecoin-0.18.1/src/qt/locale/bitcoin_he_IL.ts <==
<TS language="he_IL" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>קליל ימני כדי לערוך כתובת או תווית</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>צור כתובת חדשה</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>וחדש</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>העתק את הכתובת הנבחרת ללוח</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>והעתק</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>וסגור</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>מחק את הכתובת הנבחרת מהרשימה</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>יצא את המידע בעמוד הנוכחי לקובץ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ייצוא</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>בחר את הכתובת כדי לשלוח אליה מטבעות</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>בחר את הכתובת כדי לקבל אליה מטבעות</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>בחר</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>שולח כתובות</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>מקבל כתובות</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>אלו הן כתובות לייטקוין שלך לשליחת תשלומים. תמיד בדוק את כתובת הארנק המקבל לפני שליחת מטבעות</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>אלו הן כתובות לייטקוין שלך לקבלת תשלומים. מומלץ להשתמש בכתובת חדשה בכל העברת מטבעות</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Litecoin</source>
        <translation>ללייטקוין</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>העתק כמות</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Litecoin</source>
        <translation>ללייטקוין</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet</source>
        <translation>ארנק</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Copy quantity</source>
        <translation>העתק כמות</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy amount</source>
        <translation>העתק סכום</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ייצוא</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>יצא את המידע בעמוד הנוכחי לקובץ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
